<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fmp="http://www.filemaker.com/fmpxmlresult">

<!-- texte-biblio.xsl  (Notes de lecture, version 1.9b - janvier 2015)
	===========
 	Transforme les donnees exportees de la table "biblios" en biblio non formatée (texte utf-8)

	Parametres exportees dans dernier champ du record :
		- Titre de la bibliographie
		- infos sur les donnees (a ajouter en fin de doc)
		- regroupement des references par categorie (3e param -> $categON)
		- encadrer les parties italiques par balises (4e param -> $balisesON)

	Note : sans <xsl:strip-space elements="*"/> pour préserver retour ligne dans $infosDocument
-->


<!-- valeurs constantes 	################## A ADAPTER ########### -->
<xsl:variable name="openTagFM"> <xsl:text>[#|i|#]</xsl:text> </xsl:variable>
<xsl:variable name="closeTagFM"> <xsl:text>[#|/i|#]</xsl:text> </xsl:variable>

<xsl:variable name="cr"> <xsl:text>&#13;</xsl:text> </xsl:variable>
<xsl:variable name="lf"> <xsl:text>&#10;</xsl:text> </xsl:variable>
<xsl:variable name="wineol"> <xsl:text>&#13;&#10;</xsl:text> </xsl:variable>
<xsl:variable name="FMeol_in"> <xsl:text>&#10;</xsl:text> </xsl:variable>

<!--		PARAMETRES : extraction depuis la chaine des params exportes
		structure de la chaine : "titre[prm1]texte dernier paragraphe[prm2]booleen pour categ ON/OFF[prm3]"
-->
<xsl:variable name="params"> <xsl:value-of select="fmp:FMPXMLRESULT/fmp:RESULTSET/fmp:ROW[1]/fmp:COL[last()]"/> </xsl:variable>
<xsl:param name="titreDoc"><xsl:value-of select="substring-before($params,'[prm1]')"/></xsl:param>
<xsl:param name="infosDocument"><xsl:value-of select="substring-before(substring-after($params,'[prm1]'), '[prm2]')"/></xsl:param>
<xsl:param name="categON"><xsl:value-of select="substring-before(substring-after($params,'[prm2]'), '[prm3]')"/></xsl:param>
<xsl:param name="balisesON"><xsl:value-of select="substring-before(substring-after($params,'[prm3]'), '[prm4]')"/></xsl:param>
<!-- balises pour italique 	-->
<xsl:param name="openTagOUT"><xsl:value-of select="substring-before(substring-after($params,'[prm4]'), '[prm5]')"/></xsl:param>
<xsl:param name="closeTagOUT"><xsl:value-of select="substring-before(substring-after($params,'[prm5]'), '[prm6]')"/></xsl:param>
<xsl:param name="ajoutPuce"><xsl:value-of select="substring-after($params,'[prm6]')"/></xsl:param>

<xsl:variable name="puceCateg">
	<xsl:choose>
		<xsl:when test="$ajoutPuce=1"><xsl:value-of select="'• '"/></xsl:when>
		<xsl:otherwise><xsl:value-of select="''"/></xsl:otherwise>
	</xsl:choose>
</xsl:variable>


<!-- Caractère CR en fonction de l'encodage -->
<xsl:variable name="clean_cr">
	<xsl:choose>
		<xsl:when test="$wichEncoding=1"><xsl:value-of select="$cr"/></xsl:when>
		<xsl:when test="$wichEncoding=2"><xsl:value-of select="$wineol"/></xsl:when>
		<xsl:otherwise><xsl:value-of select="$lf"/></xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<!--		CLE pour regroupement	-->
<xsl:key name="groupKey" match="fmp:FMPXMLRESULT/fmp:RESULTSET/fmp:ROW" use="fmp:COL[1]/fmp:DATA"/>


<!--		main template	-->
<xsl:template match="fmp:FMPXMLRESULT">



	<!--		date et titre page	-->
	<xsl:value-of select="$infosDocument"/>
	<xsl:value-of select="$clean_cr"/>
	<xsl:value-of select="$titreDoc"/>
	<xsl:value-of select="$clean_cr"/>


	<xsl:choose>

	<!--			********** avec regroupement par categ -->
		<xsl:when test='$categON=1'>
			<xsl:for-each select="fmp:RESULTSET/fmp:ROW[generate-id(.)=generate-id(key('groupKey', fmp:COL[1]/fmp:DATA)[1])]">
				<xsl:variable name="currentGroup" select="key('groupKey', fmp:COL[1]/fmp:DATA)"/>
				<xsl:for-each select="$currentGroup">

					<!-- sous-titre categ si premier du groupe -->
					<xsl:if test="position()=1">
						<xsl:value-of select="$puceCateg" />
 						<xsl:value-of select="fmp:COL[1]" />
						<xsl:value-of select="$clean_cr" />
					</xsl:if>
					<!-- référence -->
					<xsl:call-template name="RefBiblio">
						<xsl:with-param name="needForm" select ="$balisesON" />
					</xsl:call-template>
					<xsl:value-of select="$clean_cr"/>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:when>

	<!--			********** biblio seule, sans regroupement -->
		<xsl:otherwise>
			<xsl:for-each select="fmp:RESULTSET/fmp:ROW">
					<xsl:call-template name="RefBiblio">
						<xsl:with-param name="needForm" select ="$balisesON" />
					</xsl:call-template>
					<xsl:value-of select="$clean_cr"/>
			</xsl:for-each>
		</xsl:otherwise>
	</xsl:choose>

</xsl:template>





<!--	 une ref. bibliographique -->

<xsl:template name="RefBiblio">
<xsl:param name="needForm"/>
	<xsl:choose>
		<xsl:when test="$needForm=1">
			<xsl:call-template name="replaceOpenAndCloseTags">
				<xsl:with-param name="str" select="normalize-space(fmp:COL[2])" />
				<xsl:with-param name="from" select ="$openTagFM"/>
				<xsl:with-param name="to" select ="$openTagOUT"/>
				<xsl:with-param name="from2" select ="$closeTagFM"/>
				<xsl:with-param name="to2" select ="$closeTagOUT"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="replaceOpenAndCloseTags">
				<xsl:with-param name="str" select="normalize-space(fmp:COL[2])" />
				<xsl:with-param name="from" select ="$openTagFM"/>
				<xsl:with-param name="to" select ="''"/>
				<xsl:with-param name="from2" select ="$closeTagFM"/>
				<xsl:with-param name="to2" select ="''"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<!--	 ****************** UTILITAIRES ****************** -->


<!--		replaceOpenAndCloseTags $str, $from, $to, $from2, $to2
		rech/remplacement d'un couple de chaine dans un paragraphe :
		pour traitement des balises entourant passages à mettre en italique
-->
<xsl:template name="replaceOpenAndCloseTags">
	<xsl:param name="str"/>
	<xsl:param name="from"/>
	<xsl:param name="to"/>
	<xsl:param name="from2"/>
	<xsl:param name="to2"/>
	<xsl:choose>
		<xsl:when test="contains($str,$from)">
			<xsl:variable name="tmp">
				<xsl:call-template name="replaceString">
					<xsl:with-param name="str" select ="$str"/>
					<xsl:with-param name="from" select ="$from2"/>
					<xsl:with-param name="to" select ="$to2"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:value-of select="substring-before($tmp,$from)"/>
			<xsl:value-of select="$to"/>
			<xsl:call-template name="replaceString">
				<xsl:with-param name="str" select ="substring-after($tmp,$from)"/>
				<xsl:with-param name="from" select ="$from"/>
				<xsl:with-param name="to" select ="$to"/>
			</xsl:call-template>
		 </xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$str"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--	 	replaceString $str, $from, $to
		rech/remplacement simple dans une chaine (recursif)
-->
<xsl:template name="replaceString">
	<xsl:param name="str"/>
	<xsl:param name="from"/>
	<xsl:param name="to"/>
	<xsl:choose>
		<xsl:when test="contains($str,$from)">
			<xsl:value-of select="substring-before($str,$from)"/>
			<xsl:value-of select="$to"/>
			<xsl:call-template name="replaceString">
				<xsl:with-param name="str" select ="substring-after($str,$from)"/>
				<xsl:with-param name="from" select ="$from"/>
				<xsl:with-param name="to" select ="$to"/>
			</xsl:call-template>
		 </xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$str"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>

